==> dexter-0.5.0.tgz: package/README.md <==
# Dexter JS 0.5.0

Dexter is a simple Test Helper to mock and spy methods and to fake the Ajax interface. It's framework independent, running with QUnit, Jasmine, Mocha, etc.

[![Build Status](https://travis-ci.org/leobalter/DexterJS.png?branch=master)](https://travis-ci.org/leobalter/DexterJS)
[![Coverage Status](https://coveralls.io/repos/leobalter/DexterJS/badge.png)](https://coveralls.io/r/leobalter/DexterJS)

## Getting Started

Download the [production version][min] or the [development version][max].

[min]: https://raw.github.com/leobalter/DexterJS/master/dist/dexter.min.js
[max]: https://raw.github.com/leobalter/DexterJS/master/dist/dexter.js

## Support

Dexter is supported and tested on:

### Node
- 0.10

### Desktop
- Firefox 4+
- Chrome 18+
- Internet Explorer 8+
- Safari 7+ (Mac OS)

### Mobile
- Firefox for Android 23+
- Chrome (Android)
- iOS 6+

## Documentation

The project documentation files are located in https://raw.github.com/leobalter/DexterJS/master/docs

## The Contributors Hall

You are welcome to join us on the list of [contributors](https://github.com/leobalter/DexterJS/graphs/contributors) for this project on *Github*.

Please, check the [Contributing](https://github.com/leobalter/DexterJS/blob/master/docs/Contributing.md) documentation, there're just a few steps.

## License
Copyright (c) 2012 Leonardo Balter
Licensed under the MIT and GPL licenses.


[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/leobalter/dexterjs/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

==> dexter-0.5.1.tgz: package/README.md <==
# Dexter JS 0.5.0

Dexter is a simple Test Helper to mock and spy methods and to fake the Ajax interface. It's framework independent, running with QUnit, Jasmine, Mocha, etc.

[![Build Status](https://travis-ci.org/leobalter/DexterJS.png?branch=master)](https://travis-ci.org/leobalter/DexterJS)
[![Coverage Status](https://coveralls.io/repos/leobalter/DexterJS/badge.png)](https://coveralls.io/r/leobalter/DexterJS)

## Getting Started

Download the [minified version][min] or the [development version][max].

[min]: https://raw.github.com/leobalter/DexterJS/master/dist/dexter.min.js
[max]: https://raw.github.com/leobalter/DexterJS/master/dist/dexter.js

You may also install Dexter from **NPM** or **Bower**:

- NPM: `npm install --save-dev dexter`
- Bower: `bower install --save-dev dexter`

## Support

Dexter is supported and tested on:

### Node
- 0.10

### Desktop
- Firefox 4+
- Chrome 18+
- Internet Explorer 8+
- Safari 7+ (Mac OS)

### Mobile
- Firefox for Android 23+
- Firefox OS
- Chrome (Android)
- iOS 6+

## Documentation

The project documentation files are located in https://raw.github.com/leobalter/DexterJS/master/docs

## The Contributors Hall

You are welcome to join us on the list of [contributors](https://github.com/leobalter/DexterJS/graphs/contributors) for this project on *Github*.

Please, check the [Contributing](https://github.com/leobalter/DexterJS/blob/master/docs/Contributing.md) documentation, there're just a few steps.

## License
Copyright (c) 2012 Leonardo Balter
Licensed under the MIT and GPL licenses.


[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/leobalter/dexterjs/trend.png)](https://bitdeli.com/free "Bitdeli Badge")
